@@ -70,7 +70,7 @@ pub mod example {
     //!     }
     //!
     //!     dep_obj! {
-    //!         pub fn obj(self as this, app: MyApp) -> MyDepType {
+    //!         pub fn obj(self as this, app: MyApp) -> (MyDepType) {
     //!             if mut {
     //!                 &mut app.my_dep_types[this.0].dep_data
     //!             } else {
@@ -126,7 +126,7 @@ pub mod example {
         }
 
         dep_obj! {
-            pub fn obj(self as this, app: MyApp) -> MyDepType {
+            pub fn obj(self as this, app: MyApp) -> (MyDepType) {
                 if mut {
                     &mut app.my_dep_types[this.0].dep_data
                 } else {
@@ -392,7 +392,7 @@ impl<ItemType: Convenient> DepVecEntry<ItemType> {
 ///     }
 ///
 ///     dep_obj! {
-///         pub fn obj(self as this, app: MyApp) -> MyDepType {
+///         pub fn obj(self as this, app: MyApp) -> (MyDepType) {
 ///             if mut {
 ///                 &mut app.my_dep_types[this.0].dep_data
 ///             } else {
@@ -1712,14 +1712,14 @@ macro_rules! dep_type_impl_raw {
 macro_rules! dep_obj {
     (
         $(
-            $vis:vis fn $name:ident (self as $this:ident, $arena:ident : $Arena:ty) -> $(optional(trait $opt_tr:tt))? $(trait $tr:tt)? $(optional($opt_ty:ty))? $($ty:ty)? {
+            $vis:vis fn $name:ident (self as $this:ident, $arena:ident : $Arena:ty) -> $(optional(trait $opt_tr:tt))? $((trait $tr:tt))? $(optional($opt_ty:ty))? $(($ty:ty))? {
                 if mut { $field_mut:expr } else { $field:expr }
             }
         )*
     ) => {
         $(
             $crate::dep_obj_impl! {
-                $vis fn $name (self as $this, $arena : $Arena) -> $(optional(trait $opt_tr))? $(trait $tr)? $(optional($opt_ty))? $($ty)? {
+                $vis fn $name (self as $this, $arena : $Arena) -> $(optional(trait $opt_tr))? $((trait $tr))? $(optional($opt_ty))? $(($ty))? {
                     if mut { $field_mut } else { $field }
                 }
             }
@@ -1814,7 +1814,7 @@ macro_rules! dep_obj_impl {
         }
     };
     (
-        $vis:vis fn $name:ident (self as $this:ident, $arena:ident : $Arena:ty) -> trait $ty:tt {
+        $vis:vis fn $name:ident (self as $this:ident, $arena:ident : $Arena:ty) -> (trait $ty:tt) {
             if mut { $field_mut:expr } else { $field:expr }
         }
     ) => {
@@ -1890,7 +1890,7 @@ macro_rules! dep_obj_impl {
         }
     };
     (
-        $vis:vis fn $name:ident (self as $this:ident, $arena:ident: $Arena:ty) -> $ty:ty {
+        $vis:vis fn $name:ident (self as $this:ident, $arena:ident: $Arena:ty) -> ($ty:ty) {
             if mut { $field_mut:expr } else { $field:expr }
         }
     ) => {
